document.addEventListener('DOMContentLoaded', () => {
  // Theme Toggle
  const themeToggle = document.querySelector('.theme-toggle');
  const prefersDark = window.matchMedia('(prefers-color-scheme: dark)');
  
  function setTheme(isDark) {
    document.documentElement.setAttribute('data-theme', isDark ? 'dark' : 'light');
    themeToggle.textContent = isDark ? '☀️' : '🌓';
  }
  
  setTheme(prefersDark.matches);
  
  themeToggle.addEventListener('click', () => {
    const isDark = document.documentElement.getAttribute('data-theme') === 'dark';
    setTheme(!isDark);
  });

  // Browser Preview Animation
  const loadingBar = document.querySelector('.loading-bar');
  
  function simulateLoading() {
    loadingBar.style.width = '0%';
    loadingBar.style.opacity = '1';
    
    let progress = 0;
    const interval = setInterval(() => {
      progress += Math.random() * 30;
      if (progress > 100) {
        progress = 100;
        setTimeout(() => {
          loadingBar.style.opacity = '0';
          clearInterval(interval);
        }, 200);
      }
      loadingBar.style.width = `${progress}%`;
    }, 200);
  }

  // URL Bar Functionality
  const urlBar = document.querySelector('.url-bar');
  urlBar.addEventListener('keypress', (e) => {
    if (e.key === 'Enter') {
      simulateLoading();
    }
  });

  // Tab Management
  const newTabBtn = document.querySelector('.new-tab-btn');
  const tabContainer = document.querySelector('.tab-container');
  
  newTabBtn.addEventListener('click', () => {
    const tab = document.createElement('div');
    tab.className = 'tab';
    tab.textContent = 'New Tab';
    tabContainer.insertBefore(tab, newTabBtn);
  });
});
